@@ -48,8 +48,9 @@ public:
     void setOpacity(qreal value)
     {
         value = digitize(value);
-        if (_opacity == value)
+        if (_opacity == value) {
             return;
+        }
 
         _opacity = value;
         setDirty();
